%bcond_with djvu
%bcond_with dvi

%global url_ver %%(echo %{version} | cut -d. -f1)
%global __provides_exclude_from ^%{_libdir}/evince/
%global __requires_exclude ^(%%(find %{buildroot}%{_libdir}/evince/ -name '*.so' | xargs -n1 basename | sort -u | paste -s -d '|' -))

Summary:       Document viewer
Name:          evince
Version:       43.1
Release:       10%{?dist}
License:       GPLv2+ and GPLv3+ and LGPLv2+ and MIT and Afmparse
URL:           https://wiki.gnome.org/Apps/Evince
Source0:       https://download.gnome.org/sources/evince/%{url_ver}/%{name}-%{version}.tar.xz

Patch3000:     evince-42-poppler-requirement-decrease.patch

BuildRequires: gcc gettext-devel pkgconfig(gspell-1) pkgconfig(gstreamer-1.0)
BuildRequires: pkgconfig(adwaita-icon-theme) pkgconfig(dbus-1) pkgconfig(gio-unix-2.0)
BuildRequires: pkgconfig(gnome-desktop-3.0) pkgconfig(gobject-introspection-1.0) pkgconfig(libarchive)
BuildRequires: pkgconfig(gstreamer-base-1.0) pkgconfig(gstreamer-video-1.0) pkgconfig(gtk+-x11-3.0)
BuildRequires: pkgconfig(libhandy-1) pkgconfig(libsecret-1) pkgconfig(libspectre) pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(poppler-glib) libtiff-devel yelp-tools /usr/bin/desktop-file-validate
BuildRequires: libappstream-glib-devel meson systemd-rpm-macros pkgconfig(libgxps)
%if %{with dvi}
BuildRequires: texlive-lib-devel
%endif
%if %{with djvu}
BuildRequires: djvulibre-devel
%endif

Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-previewer = %{version}-%{release}
Requires: %{name}-thumbnailer = %{version}-%{release}

%description
Evince is simple multi-page document viewer. It can display and print Portable Document Format
(PDF), PostScript (PS) and Encapsulated PostScript (EPS) files. When supported by the document
format, evince allows searching for text, copying text to the clipboard, hypertext navigation,
table-of-contents bookmarks and editing of forms.

Support for other document formats such as DVI and DJVU can be added by installing additional
backends.

%package libs
Summary: Libraries for the evince document viewer
%if %{with djvu}
Recommends: %{name}-djvu = %{version}-%{release}
%endif
Requires:   libarchive poppler-glib

%description libs
This package contains shared libraries needed for evince

%package devel
Summary: Support for developing backends for the evince document viewer
Requires: %{name}-libs = %{version}-%{release}

%description devel
This package contains libraries and header files needed for evince backend development.

%if %{with dvi}
%package dvi
Summary: Evince backend for dvi files
Requires: %{name}-libs = %{version}-%{release}
Requires: texlive-collection-fontsrecommended

%description dvi
This package contains a backend to let evince display dvi files.
%endif

%if %{with djvu}
%package djvu
Summary: Evince backend for djvu files
Requires: %{name}-libs = %{version}-%{release}

%description djvu
This package contains a backend to let evince display djvu files.
%endif

%package thumbnailer
Summary: Evince thumbnailer
Requires: %{name}-libs = %{version}-%{release}

%description thumbnailer
This package brings the Evince thumbnailer independently from Evince.

%package previewer
Summary: Evince previewer
Requires: %{name}-libs = %{version}-%{release}

%description previewer
This package brings the Evince previewer independently from Evince.
It provides the printing preview for the GTK printing dialog.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%meson \
        -Dcomics=enabled \
%if %{with dvi}
        -Ddvi=enabled \
%else
        -Ddvi=disabled \
%endif
        -Ddjvu=disabled \
        -Dxps=enabled \
        -Dnautilus=false \
        -Dps=enabled \
        -Dgtk_doc=false
%meson_build

%install
%meson_install

%find_lang evince --with-gnome

mkdir -p %{buildroot}%{_datadir}/applications
rm -f %{buildroot}%{_datadir}/metainfo/evince-pdfdocument.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/evince-psdocument.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/evince-tiffdocument.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/evince-comicsdocument.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/evince-xpsdocument.metainfo.xml

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Evince.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Evince.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Evince-previewer.desktop

%files -f evince.lang
%{_userunitdir}/org.gnome.Evince.service
%{_bindir}/evince
%{_bindir}/evince-previewer
%{_libexecdir}/evinced
%{_datadir}/applications/org.gnome.Evince.desktop
%{_datadir}/applications/org.gnome.Evince-previewer.desktop
%{_datadir}/evince/
%{_datadir}/icons/hicolor/*/apps/org.gnome.Evince.*
%{_datadir}/icons/hicolor/*/apps/org.gnome.Evince-symbolic.svg
%{_datadir}/dbus-1/services/org.gnome.evince.Daemon.service
%{_datadir}/glib-2.0/schemas/org.gnome.Evince.gschema.xml
%{_datadir}/GConf/gsettings/evince.convert
%{_datadir}/metainfo/org.gnome.Evince.appdata.xml
%{_mandir}/man1/evince.1*
%{_mandir}/man1/evince-previewer.1*

%files libs
%license COPYING
%doc NEWS AUTHORS
%{_libdir}/libevdocument3.so.4*
%{_libdir}/libevview3.so.3*
%dir %{_libdir}/evince
%dir %{_libdir}/evince/4
%dir %{_libdir}/evince/4/backends
%{_libdir}/evince/4/backends/libpdfdocument.so
%{_libdir}/evince/4/backends/pdfdocument.evince-backend
%{_libdir}/evince/4/backends/libpsdocument.so
%{_libdir}/evince/4/backends/psdocument.evince-backend
%{_libdir}/evince/4/backends/libtiffdocument.so
%{_libdir}/evince/4/backends/tiffdocument.evince-backend
%{_libdir}/evince/4/backends/libcomicsdocument.so
%{_libdir}/evince/4/backends/comicsdocument.evince-backend
%{_libdir}/evince/4/backends/libxpsdocument.so
%{_libdir}/evince/4/backends/xpsdocument.evince-backend
%{_libdir}/girepository-1.0/EvinceDocument-3.0.typelib
%{_libdir}/girepository-1.0/EvinceView-3.0.typelib

%files devel
%dir %{_includedir}/evince
%{_includedir}/evince/3.0
%{_libdir}/libevview3.so
%{_libdir}/libevdocument3.so
%{_libdir}/pkgconfig/evince-view-3.0.pc
%{_libdir}/pkgconfig/evince-document-3.0.pc
%{_datadir}/doc/evince-libs
%{_datadir}/gir-1.0/EvinceDocument-3.0.gir
%{_datadir}/gir-1.0/EvinceView-3.0.gir

%if %{with dvi}
%files dvi
%{_libdir}/evince/4/backends/libdvidocument.so*
%{_libdir}/evince/4/backends/dvidocument.evince-backend
%{_datadir}/metainfo/evince-dvidocument.metainfo.xml
%endif

%if %{with djvu}
%files djvu
%{_libdir}/evince/4/backends/libdjvudocument.so
%{_libdir}/evince/4/backends/djvudocument.evince-backend
%{_datadir}/metainfo/evince-djvudocument.metainfo.xml
%endif

%files thumbnailer
%{_bindir}/evince-thumbnailer
%{_datadir}/thumbnailers/evince.thumbnailer
%{_mandir}/man1/evince-thumbnailer.1*

%files previewer
%{_bindir}/evince-previewer
%{_mandir}/man1/evince-previewer.1*

%changelog
* Tue Dec 24 2024 Rebuild Robot <rebot@opencloudos.org> - 43.1-10
- [Type] other
- [DESC] Rebuilt for gtk3

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-9
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Mon Sep 23 2024 Shuo Wang <abushwang@tencent.com> - 43.1-8
- update source0 url

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-7
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-6
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 43.1-5
- Rebuilt for libtiff 4.5.1

* Mon Jul 17 2023 Xiaojie Chen <jackxjchen@tencent.com> - 43.1-4
- Rebuilt for gstreamer1-plugins-base 1.22.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 9 2023 Shuo Wang <abushwang@tencent.com> - 43.1-1
- initial build
